@@ -41,7 +41,7 @@ def list_of_out_directories(fpath):
     return dire
 
 def _parsing_poscar(lines):
-        name = lines[0]
+        name = lines[0][:-1]
         lattice_cons = float(lines[1])
         basex = np.array([float(l)*lattice_cons for l in lines[2].split()])
         basey = np.array([float(l)*lattice_cons for l in lines[3].split()])
@@ -234,16 +234,16 @@ def to_poscar(
     poscar = [name]
     poscar.append('\n')
     poscar.append('1.0\n')
-    poscar.append('\t'+str(basex[0])+'\t'+str(basex[1]) +'\t' + str(basex[2]) + '\n')
-    poscar.append('\t'+str(basey[0])+'\t'+str(basey[1]) +'\t' + str(basey[2]) + '\n')
-    poscar.append('\t'+str(basez[0])+'\t'+str(basez[1]) +'\t' + str(basez[2]) + '\n')
-    poscar.append('\t'+'\t'.join(atoms_type) + '\n')
-    poscar.append('\t'+'\t'.join([str(a) for a in atoms_quantity]) + '\n')
-    poscar.append(' '+cart_dir+'\n')
+    poscar.append('\t'+"{:15.10f}".format(basex[0])+'         '+"{:15.10f}".format(basex[1])+'         '+"{:15.10f}".format(basex[2]) + '\n')
+    poscar.append('\t'+"{:15.10f}".format(basey[0])+'         '+"{:15.10f}".format(basey[1])+'         '+"{:15.10f}".format(basey[2]) + '\n')
+    poscar.append('\t'+"{:15.10f}".format(basez[0])+'         '+"{:15.10f}".format(basez[1])+'         '+"{:15.10f}".format(basez[2]) + '\n')
+    poscar.append(''.join(["{:>5}".format(at) for at in atoms_type]) + '\n')
+    poscar.append(''.join(["{:>5}".format(aq) for aq in atoms_quantity]) + '\n')
+    poscar.append(cart_dir+'\n')
     for positions in positions_splited:
         if len(positions.shape)>1:
             for p in positions:
-                poscar.append(str(p[0]) + '\t' + str(p[1]) + '\t' + str(p[2]) + '\t' + '\n')
+                poscar.append("{:16.9f}".format(p[0]) +'    '+ "{:16.9f}".format(p[1]) +'    '+ "{:16.9f}".format(p[2]) + '\t' + '\n')
         else:
             poscar.append(str(positions[0]) + '\t' + str(positions[1]) + '\t' + str(positions[2]) + '\t' + '\n')
     poscar = "".join(poscar)
@@ -352,6 +352,7 @@ def to_lammps(
                         '   ' +
                         str(n) + ' ' +
                         str(at+1) + ' ' +
+                        '0 ' +
                         str(a[0]) + ' ' + 
                         str(a[1]) + ' ' + 
                         str(a[2]) + ' ' + 
@@ -542,76 +543,80 @@ def read_charge(fpath):
 def vasp_to_runner_data_train(finput):
     samples = list_of_directories(finput)
     text = ''
-    for sample in samples:
-        #charges and positions   
-        file = open(finput + sample + '/POTCAR')
-        lines = file.readlines()
-        file.close()
-        energy = [lines[i+1] for i in np.arange(len(lines)) if '  PAW_PBE' in lines[i]]
-        charges_default = np.array(energy, dtype=float)
+    for sample, nsample in zip(samples, range(len(samples))):
+        try:
+            #charges and positions   
+            file = open(finput + sample + '/POTCAR')
+            lines = file.readlines()
+            file.close()
+            energy = [lines[i+1] for i in np.arange(len(lines)) if '  PAW_PBE' in lines[i]]
+            charges_default = np.array(energy, dtype=float)
 
-        file = open(finput + sample + '/ACF.dat')
-        lines = file.readlines()
-        file.close()
-        total_electrones = float(lines[-1].split()[-1])
-        lines = lines[2:-4]
-        positions = np.array([l.split()[1:4] for l in lines], dtype=float)*Angstrom_2_Bohr
-        positions = np.array(positions, dtype='str')
-        charges_ = np.array([l.split()[4] for l in lines], dtype=float)
+            file = open(finput + sample + '/ACF.dat')
+            lines = file.readlines()
+            file.close()
+            total_electrones = float(lines[-1].split()[-1])
+            lines = lines[2:-4]
+            positions = np.array([l.split()[1:4] for l in lines], dtype=float)*Angstrom_2_Bohr
+            positions = np.array(positions, dtype='str')
+            charges_ = np.array([l.split()[4] for l in lines], dtype=float)
 
-        file = open(finput + sample + '/POSCAR')
-        lines = file.readlines()
-        atoms = lines[6].split()
-        atoms_names = lines[5].split()
-        file.close()
-        atoms = [int(a) for a in atoms]
-        charges_default_vec = []
-        atoms_names_vec = []
-        for a, cd, an in zip(atoms, charges_default, atoms_names):
-            charges_default_vec = charges_default_vec + [cd]*a
-            atoms_names_vec = atoms_names_vec + [an]*a
-        charges_default_vec = np.array(charges_default_vec)
-        charges = (-charges_+charges_default_vec).tolist()
-        charges = [str(c) for c in charges]
-        basis = lines[2:5]
+            file = open(finput + sample + '/POSCAR')
+            lines = file.readlines()
+            atoms = lines[6].split()
+            atoms_names = lines[5].split()
+            file.close()
+            atoms = [int(a) for a in atoms]
+            charges_default_vec = []
+            atoms_names_vec = []
+            for a, cd, an in zip(atoms, charges_default, atoms_names):
+                charges_default_vec = charges_default_vec + [cd]*a
+                atoms_names_vec = atoms_names_vec + [an]*a
+            charges_default_vec = np.array(charges_default_vec)
+            charges = (-charges_+charges_default_vec).tolist()
+            charges = [str(c) for c in charges]
+            basis = lines[2:5]
 
-        #forces
-        file = open(finput + sample + '/OUTCAR')
-        lines = file.readlines()[2:-4]
-        file.close()
-        energy = [l for l in lines if 'energy  without entropy' in l]
-        energy = str(float(energy[-1].split('=')[1].split()[0])*ev2H)
+            #forces
+            file = open(finput + sample + '/OUTCAR')
+            lines = file.readlines()[2:-4]
+            file.close()
+            energy = [l for l in lines if 'energy  without entropy' in l]
+            energy = str(float(energy[-1].split('=')[1].split()[0])*ev2H)
 
-        start = [i for i in range(len(lines)) if 'TOTAL-FORCE' in lines[i]]
-        lines = lines[start[-1]+2:]
-        stop = [i for i in range(len(lines)) if 'total drift:' in lines[i]]
-        lines = lines[:stop[-1]-1]
-        forces = np.array([l.split()[3:] for l in lines], dtype=float)
-        forces = np.array(forces*eV_per_Angstrom_2_Ha_per_Bohr, dtype='str')
+            start = [i for i in range(len(lines)) if 'TOTAL-FORCE' in lines[i]]
+            lines = lines[start[-1]+2:]
+            stop = [i for i in range(len(lines)) if 'total drift:' in lines[i]]
+            lines = lines[:stop[-1]-1]
+            forces = np.array([l.split()[3:] for l in lines], dtype=float)
+            forces = np.array(forces*eV_per_Angstrom_2_Ha_per_Bohr, dtype='str')
 
-        text = text + 'begin\n'
-        text = text + 'lattice         '+'   '.join((np.array(np.array(basis[0].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
-        text = text + 'lattice         '+'   '.join((np.array(np.array(basis[1].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
-        text = text + 'lattice         '+'   '.join((np.array(np.array(basis[2].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
-        lines = ''
-        for i in range(len(atoms_names_vec)):
-            line = [
-                    'atom',
-                    ("%.10f" % float(positions[i][0])),
-                    ("%.10f" % float(positions[i][1])),
-                    ("%.10f" % float(positions[i][2])),
-                    atoms_names_vec[i],
-                    ("%.10f" % float(charges[i])),
-                    '0',
-                    ("%.10f" % float(forces[i][0])),
-                    ("%.10f" % float(forces[i][1])),
-                    ("%.10f" % float(forces[i][2])),
-                    ]
-            lines = lines + ''.join(word.ljust(15) for word in line)+'\n'
-        text = text + lines
-        text = text + 'energy    ' + energy + '\n'
-        text = text + 'charge    '+str(-np.sum(charges_default_vec)+total_electrones)+ '\n'
-        text = text + 'end\n'
+            text = text + 'begin\n'
+            text = text + 'lattice         '+'   '.join((np.array(np.array(basis[0].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
+            text = text + 'lattice         '+'   '.join((np.array(np.array(basis[1].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
+            text = text + 'lattice         '+'   '.join((np.array(np.array(basis[2].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
+            lines = ''
+            for i in range(len(atoms_names_vec)):
+                line = [
+                        'atom',
+                        ("%.10f" % float(positions[i][0])),
+                        ("%.10f" % float(positions[i][1])),
+                        ("%.10f" % float(positions[i][2])),
+                        atoms_names_vec[i],
+                        ("%.10f" % float(charges[i])),
+                        '0',
+                        ("%.10f" % float(forces[i][0])),
+                        ("%.10f" % float(forces[i][1])),
+                        ("%.10f" % float(forces[i][2])),
+                        ]
+                lines = lines + ''.join(word.ljust(15) for word in line)+'\n'
+            text = text + lines
+            text = text + 'energy    ' + energy + '\n'
+            text = text + 'charge    '+str(-np.sum(charges_default_vec)+total_electrones)+ '\n'
+            text = text + 'end\n'
+            print("\r" + str(int(100*(nsample+1)/len(samples))) + "%        ", end='')
+        except:
+            print('skipping entry!!! problem with data in folder '+sample)
 
     file = open(finput + '/input.data', 'w')
     file.writelines(text)
